"""
Copyright 2021-2023 MICRORISC s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

	http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from dataclasses import dataclass
from typing import Optional


@dataclass
class DeviceInfo:
	"""
	Device information entity class.

	Attributes
	----------
	gwid: str
		gateway id
	address: int
		network device address
	index: int
		sensor index
	"""

	def __init__(self, gwid: str, address: Optional[int] = None, index: Optional[int] = None) -> None:
		"""
		Construct attributes for measurement entity object.

		Parameters
		----------
		gwid: str
			gateway id
		address: int
			network device address
		index: int
			sensor index
		"""
		self.gwid: str = gwid
		self.address: Optional[int] = address
		self.index: Optional[int] = index

	def to_dict(self) -> dict:
		"""
		Serialize device information entity to dictionary.

		Parameters
		----------
		None

		Returns
		-------
		dict
			Measurement entity serialized to dictionary.
		"""
		json = {
			'gwId': f'gw_{self.gwid}'.lower(),
		}
		if self.address is not None:
			json['nAdr'] = self.address
		if self.index is not None:
			json['idx'] = self.index
		return json
