"""
Copyright 2021-2023 MICRORISC s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

	http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from dataclasses import dataclass
from .DeviceInfo import DeviceInfo


@dataclass
class Measurement:
	"""
	Measurement entity class.

	Attributes
	----------
	device: DeviceInfo
		device information
	name: str
		measurement name
	value: float
		measured value

	Methods
	-------
	to_dict():
		Serializes measurement entity to dict.
	to_point():
		Creates Influxdb point from measurement entity.
	"""

	def __init__(self, device: DeviceInfo, name: str, value: float) -> None:
		"""
		Construct attributes for measurement entity object.

		Parameters
		----------
		device: DeviceInfo
			device information
		name: str
			measurement name
		value: float
			measured value
		"""
		self.device: DeviceInfo = device
		self.name: str = name
		self.value: float = value

	def to_dict(self) -> dict:
		"""
		Serialize measurement entity to dictionary.

		Parameters
		----------
		None

		Returns
		-------
		dict
			Measurement entity serialized to dictionary.
		"""
		return {
			'measurement': self.name,
			'tags': self.device.to_dict(),
			'fields': {
				'value': self.value
			}
		}
